@@ -12,7 +12,8 @@ use warnings;
 use Getopt::Long;
 use Pod::Usage;
 use FindBin;
-use lib "$FindBin::Bin/../lib";
+use File::Spec;
+use lib File::Spec->catdir( $FindBin::Bin, '..', 'lib' );
 
 my $debug             = 0;
 my $fork              = 0;
