@@ -5,13 +5,14 @@ use FindBin qw/$RealBin/;
 use Cwd qw/abs_path/;
 use Perl::Critic;
 use File::Next;
+use File::Spec;
 
-my $path = abs_path("$RealBin/../..");
+my $path = abs_path( File::Spec->catdir( $RealBin, '..', '..' ) );
 
 my $files  = File::Next::files($path);
 my $critic = Perl::Critic->new();
 
-open( my $fh, '>', "$RealBin/critic.txt" );
+open( my $fh, '>', File::Spec->catfile( $RealBin, 'critic.txt' ) );
 flock( $fh, 2 );
 
 while ( defined( my $file = $files->() ) ) {
