@@ -20,16 +20,17 @@ my ( undef, $path ) = File::Spec->splitpath(__FILE__);
 
 sub base_path {
     return $base_path if ($base_path);
-    $base_path = abs_path("$path/../../../");
+    $base_path = abs_path( File::Spec->catdir( $path, '..', '..', '..' ) );
     return $base_path;
 }
 
 sub config {
     return $config if ($config);
 
-    $config = LoadFile("$path/../../../foorum.yml");
-    if ( -e "$path/../../../foorum_local.yml" ) {
-        my $extra_config = LoadFile("$path/../../../foorum_local.yml");
+    $config = LoadFile( File::Spec->catfile( $path, '..', '..', '..', 'foorum.yml' ) );
+    if ( -e File::Spec->catfile( $path, '..', '..', '..', 'foorum_local.yml' ) ) {
+        my $extra_config = LoadFile(
+            File::Spec->catfile( $path, '..', '..', '..', 'foorum_local.yml' ) );
         $config = { %$config, %$extra_config };
     }
     return $config;
@@ -48,7 +49,7 @@ sub schema {
     };
 
     # create the database
-    my $db_file = "$path/test.db";
+    my $db_file = File::Spec->catfile( $path, 'test.db' );
     my $schema
         = Foorum::Schema->connect( "dbi:SQLite:$db_file", '', '',
         { AutoCommit => 1, RaiseError => 1, PrintError => 1 },
